# UserConfigPropertyRentSubscriptionsInner


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from iam.v1.models.user_config_property_rent_subscriptions_inner import UserConfigPropertyRentSubscriptionsInner

# TODO update the JSON string below
json = "{}"
# create an instance of UserConfigPropertyRentSubscriptionsInner from a JSON string
user_config_property_rent_subscriptions_inner_instance = UserConfigPropertyRentSubscriptionsInner.from_json(json)
# print the JSON string representation of the object
print(UserConfigPropertyRentSubscriptionsInner.to_json())

# convert the object into a dict
user_config_property_rent_subscriptions_inner_dict = user_config_property_rent_subscriptions_inner_instance.to_dict()
# create an instance of UserConfigPropertyRentSubscriptionsInner from a dict
user_config_property_rent_subscriptions_inner_from_dict = UserConfigPropertyRentSubscriptionsInner.from_dict(user_config_property_rent_subscriptions_inner_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


